@@ -26,8 +26,8 @@
 #include <iostream>
 #include <stdlib.h>
 
-#include "../Common.hpp"
-#include "../fatal.h"
+#include "../Common.hpp"  // EDIT BY SJ
+#include "../fatal.h"  // EDIT BY SJ
 
 #include "CustomWave.hpp"
 #include "CustomShape.hpp"
@@ -42,7 +42,7 @@
 #include <map>
 #include "ParamUtils.hpp"
 
-#include "../wipemalloc.h"
+#include "../wipemalloc.h"  // EDIT BY SJ
 #include <iostream>
 #include <sstream>
 #include "BuiltinFuncs.hpp"
@@ -199,7 +199,7 @@ sj_token_t Parser::parseToken(std::istream &  fs, char * string)
 			if (fs)
 				fs.unget();
 			else
-				abort();
+				return tEOL;//abort(); - EDIT BY SJ - everything, but not program abort!
 		}
 		return tEOL;
 	}
@@ -1735,7 +1735,7 @@ void Parser::readStringUntil(std::istream & fs, std::string * out_buffer, bool w
 							if (fs)
 								fs.unget();
 							else
-								abort();
+								return; // abort(); -- EDIT BY SJ -- everything but no program abort!
 						}
 						return;
 					}
