@@ -19,13 +19,13 @@
 *
 */
 
-#include "Renderer/RenderItemMatcher.hpp"
-#include "Renderer/RenderItemMergeFunction.hpp"
+#include "Renderer/RenderItemMatcher.hpp"  // EDIT BY SJ
+#include "Renderer/RenderItemMergeFunction.hpp"  // EDIT BY SJ
 #include "fatal.h"
 #include "Common.hpp"
 
 #ifdef WIN32
-#include <dirent-win32/dirent.h>
+#include <dirent-win32/dirent.h>  // EDIT BY SJ
 #endif
 
 #include "timer.h"
@@ -37,28 +37,28 @@
 #ifdef WIN32
 #include <time.h>
 #endif
-#include "Renderer/PipelineContext.hpp"
+#include "Renderer/PipelineContext.hpp"  // EDIT BY SJ
 #include <iostream>
 #include "projectM.hpp"
-#include "Renderer/BeatDetect.hpp"
+#include "Renderer/BeatDetect.hpp"  // EDIT BY SJ
 #include "Preset.hpp"
 #include "PipelineMerger.hpp"
 #include "PCM.hpp"                    //Sound data handler (buffering, FFT, etc.)
 
 #include <map>
 
-#include "Renderer/Renderer.hpp"
+#include "Renderer/Renderer.hpp"  // EDIT BY SJ
 #include "PresetChooser.hpp"
 #include "ConfigFile.h"
-#include "Renderer/TextureManager.hpp"
+#include "Renderer/TextureManager.hpp"  // EDIT BY SJ
 #include "TimeKeeper.hpp"
-#include "Renderer/RenderItemMergeFunction.hpp"
+#include "Renderer/RenderItemMergeFunction.hpp"  // EDIT BY SJ
 
 #ifdef USE_THREADS
 #ifdef __WXMSW__
-#include <pthread-win32/pthread.h>
+#include <pthread-win32/pthread.h>  // EDIT BY SJ
 #else
-#include "pthread.h"
+#include "pthread.h"  // EDIT BY SJ
 #endif
 
 pthread_mutex_t mutex;
@@ -94,6 +94,10 @@ projectM::~projectM()
     printf("p");
     std::cout << std::endl;
     #endif
+
+    m_activePreset.reset();  // FIXED: EDIT BY SJ: m_activePreset->presetOutput is a pointer to m_presetLoader->_presetFactoryManager->_factoryList->_presetOutputs2 which is destroyed by destroyPresetTools()
+    m_activePreset2.reset(); // so, make sure, it is released before destroyPresetTools() (not implicitly after the destructor)
+
     destroyPresetTools();
 
     if ( renderer )
@@ -107,9 +111,10 @@ projectM::~projectM()
 
     delete(_pipelineContext);
     delete(_pipelineContext2);
-	#ifdef WIN32
-	m_activePreset.release(); // EDIT BY SJ - don't know why, but the pointer m_activePreset points to is bad at this time
-	#endif
+
+	if( timeKeeper ) { delete(timeKeeper); } // EDIT BY SJ: Fix a memory leak
+	if( _merger    ) { delete(_merger);    } // EDIT BY SJ: Fix a memory leak
+	if( _matcher   ) { delete(_matcher);   } // EDIT BY SJ: Fix a memory leak
 }
 
 unsigned projectM::initRenderToTexture()
@@ -123,6 +128,7 @@ void projectM::projectM_resetTextures()
 }
 
 
+/* EDIT BY SJ
 projectM::projectM ( std::string config_file, int flags) :
 beatDetect ( 0 ), renderer ( 0 ),  _pcm(0), m_presetPos(0), m_flags(flags), _pipelineContext(new PipelineContext()), _pipelineContext2(new PipelineContext())
 {
@@ -131,8 +137,9 @@ beatDetect ( 0 ), renderer ( 0 ),  _pcm(0), m_presetPos(0), m_flags(flags), _pip
     projectM_resetGL(_settings.windowWidth, _settings.windowHeight);
 
 }
+*/
 
-projectM::projectM(const Settings& settings, int flags):
+projectM::projectM(const Settings& settings, int flags):  // EDIT BY SJ
 beatDetect ( 0 ), renderer ( 0 ),  _pcm(0), m_presetPos(0), m_flags(flags), _pipelineContext(new PipelineContext()), _pipelineContext2(new PipelineContext())
 {
     readSettings(settings);
@@ -141,6 +148,7 @@ beatDetect ( 0 ), renderer ( 0 ),  _pcm(0), m_presetPos(0), m_flags(flags), _pip
 }
 
 
+/* EDIT BY SJ
 bool projectM::writeConfig(const std::string & configFile, const Settings & settings) {
 
     ConfigFile config ( configFile );
@@ -168,9 +176,10 @@ bool projectM::writeConfig(const std::string & configFile, const Settings & sett
     } else
         return false;
 }
+*/
 
 
-
+/* EDIT BY SJ
 void projectM::readConfig (const std::string & configFile )
 {
     std::cout << "[projectM] config file: " << configFile << std::endl;
@@ -246,7 +255,7 @@ void projectM::readConfig (const std::string & configFile )
 
 
 }
-
+*/
 
 void projectM::readSettings (const Settings & settings )
 {
@@ -882,7 +891,7 @@ void projectM::switchPreset(std::auto_ptr<Preset> & targetPreset) {
     {
         bool atEndPosition = false;
 
-        int newSelectedIndex = 0;
+        int newSelectedIndex = 0; // EDIT BY SJ
 
 
         if (*m_presetPos == m_presetChooser->end()) // Case: preset not selected
