@@ -321,6 +321,14 @@ bool SjMainFrame::UpdateIndex(wxWindow* parent, bool deepUpdate)
 
 				moduleNode = moduleNode->GetNext();
 			}
+
+			if( ret )
+			{
+				// Cleanup the caches.
+				// (needed to remove cached HTTP-files, covers from RAM etc.)
+				SjBusyInfo::Set(_("Cleanup caches"), true);
+				m_imgThread->CleanupAllCaches(); // this also calls SjTempNCache::CleanupFiles();
+			}
 		}
 
 		if( ret )
@@ -359,6 +367,13 @@ bool SjMainFrame::QueryEndSession(bool onShutdown)
 		if( !onShutdown
 		 &&  IsPlaying() )
 		{
+			#ifdef __WXMSW__
+				// THIS IS A HACK: If an OpenGL visualisation is active, the program-quit seems not to reach
+				// the main queue until the OpenGL wndow ist closed. So a click on "Exit" does nothing - but if the  OpenGL visualisation
+				// is closed (minutes) later, the program terminates.
+				// we fix this by simply closing the OpenGL visualisation before terminating the program.
+				g_visModule->StopVis();
+			#endif
 			if( g_accelModule->YesNo(
 			            wxString::Format(_("%s is currently playing. Do you want to stop the playing track and exit %s?"),
 			                             SJ_PROGRAM_NAME, SJ_PROGRAM_NAME
@@ -1447,7 +1462,8 @@ BEGIN_EVENT_TABLE(SjMainFrame, SjSkinWindow)
 	EVT_MENU        (IDO_SETTINGS_SKINS,                        SjMainFrame::OnFwdToSkin     )
 	EVT_MENU        (IDO_SETTINGS_FONTNCOVER,                   SjMainFrame::OnFwdToSkin     )
 	EVT_MENU        (IDO_SETTINGS_QUEUE,                        SjMainFrame::OnFwdToSkin     )
-	EVT_MENU        (IDO_SETTINGS_AUTOVOL,                      SjMainFrame::OnFwdToSkin     )
+	EVT_MENU        (IDO_SETTINGS_AUTOCTRL,                     SjMainFrame::OnFwdToSkin     )
+	EVT_MENU        (IDO_SETTINGS_EQUALIZER,                    SjMainFrame::OnFwdToSkin     )
 	EVT_MENU        (IDO_REALLYENDSEARCH,                       SjMainFrame::OnFwdToSkin     )
 	EVT_MENU        (IDO_CORNERCLICK,                           SjMainFrame::OnFwdToSkin     )
 	EVT_MENU        (IDO_ABOUT_OPEN_WWW,                        SjMainFrame::OnFwdToSkin     )
@@ -1567,9 +1583,14 @@ void SjMainFrame::OnSkinTargetEvent(int targetId, SjSkinValue& value, long accel
 	      ||  targetId == IDT_ZOOM_OUT
 	      ||  targetId == IDT_ZOOM_NORMAL )
 	{
-		// this stuff will be forwarded to the browser
+		// this stuff will be forwarded to the browser (or some keys to the vis.)
 		// (we may come from there, but this is not necessarily the case, eg. when using "real" accelerators or buttons for this)
-		m_browser->OnSkinTargetEvent(targetId, value, accelFlags);
+		if( g_visModule->IsOverWorkspace() && (targetId >= IDT_WORKSPACE_KEY_LEFT && targetId <= IDT_WORKSPACE_KEY_DOWN) ) {
+			g_visModule->OnVisMenu(targetId);
+		}
+		else {
+			m_browser->OnSkinTargetEvent(targetId, value, accelFlags);
+		}
 	}
 	else if( targetId >= IDT_LAYOUT_FIRST && targetId <= IDT_LAYOUT_LAST )
 	{
@@ -1756,8 +1777,15 @@ void SjMainFrame::OnSkinTargetEvent(int targetId, SjSkinValue& value, long accel
 				}
 				break;
 
+			case IDO_SETTINGS_EQUALIZER:
+				if( IsAllAvailable() )
+				{
+					OpenSettings("memory:fxsettings.lib", 0, 0);
+				}
+				break;
+
 			case IDO_SETTINGS_QUEUE:
-			case IDO_SETTINGS_AUTOVOL:
+			case IDO_SETTINGS_AUTOCTRL:
 				if( IsAllAvailable() )
 				{
 					OpenSettings("memory:playbacksettings.lib", 0, targetId==IDO_SETTINGS_QUEUE? 0 : 2);
@@ -1839,12 +1867,9 @@ void SjMainFrame::OnSkinTargetEvent(int targetId, SjSkinValue& value, long accel
 				/*else fall through*/
 			case IDT_TOGGLE_TIME_MODE:
 			case IDO_TOGGLE_TIME_MODE2:
-				if( IsOpAvailable(SJ_OP_TOGGLE_TIME_MODE) )
-				{
-					m_showRemainingTime = !m_showRemainingTime;
-					UpdateDisplay();
-					UpdateMenuBarQueue();
-				}
+				m_showRemainingTime = !m_showRemainingTime;
+				UpdateDisplay();
+				UpdateMenuBarQueue();
 				break;
 
 			case IDO_DISPLAY_TOTAL_TIME:
@@ -1907,7 +1932,7 @@ void SjMainFrame::OnSkinTargetEvent(int targetId, SjSkinValue& value, long accel
 			case IDT_STOP:
 				if( IsOpAvailable(SJ_OP_PLAYPAUSE) )
 				{
-					Stop();
+					Stop(false);
 				}
 				break;
 
@@ -1998,6 +2023,14 @@ void SjMainFrame::OnSkinTargetEvent(int targetId, SjSkinValue& value, long accel
 					if( targetId == IDT_ENQUEUE_NOW && IsOpAvailable(SJ_OP_EDIT_QUEUE) )
 					{
 						enqueuePos = -3;
+						if( m_player.IsPlaying() )
+						{
+							if( g_accelModule->YesNo(_("Interrupt the playing track and continue with the new selection?"),
+							  _("Interrupt playing track"), this, SJ_ACCEL_ASK_ON_INTERRUPTING) != wxYES )
+							{
+								return;
+							}
+						}
 					}
 
 					Enqueue(urls, enqueuePos, TRUE/*verified*/);
