@@ -41,7 +41,7 @@ public:
 
 class SjBackend;
 class SjBackendStream;
-class SjBackendCallbackParam;
+struct SjBackendCallbackParam;
 class SjVolumeCalc;
 
 
@@ -61,17 +61,13 @@ public:
 	void            LoadFromResumeFile  ();
 	wxString        GetResumeFile       () const;
 
-	// Check if a given file is playable
-	bool            TestUrl             (const wxString& url);
-	const SjExtList* GetExtList         ();
-
 	// Basic Player Control.
 	// The playback is NOT started implicit by Goto() or Enqueue() functions.
 	// To check if the operations were successfull, use the Is*()/Get*() functions.
 	void            Play                (long ms=0);
 	void            Pause               ();
 	void            PlayOrPause         ()                                  { if(IsPlaying()) {Pause();} else {Play(0);} }
-	void            Stop                (bool stopVisIfPlaying=true);
+	void            Stop                (bool stopVisIfPlaying=true, bool keepPrelisten=true);
 	void            StopAfterThisTrack  (bool s)                            { m_stopAfterThisTrack=s; }
 	bool            StopAfterThisTrack  () const                            { return m_stopAfterThisTrack; }
 	void            StopAfterEachTrack  (bool s)                            { m_stopAfterEachTrack=s; }
@@ -82,8 +78,9 @@ public:
 	wxString        GetUrlOnAir         ();
 	bool            IsAutoPlayOnAir     ();
 	bool            IsVideoOnAir        (); // has the running title a video stream?
-	bool            AreTheseUrlsCurrentlyPrelistening(const wxArrayString&) { return false; }
-	void            TogglePrelisten     (const wxArrayString& urls) {}
+	void            TogglePrelisten     (const wxArrayString& urls);
+	bool            IsPrelistening      () const { return (m_prelistenStream!=NULL); }
+	void            GetPrelistenInfo    (wxString& url, long& totalMs, long& elapsedMs, long& remainingMs);
 
 	// Handling the main volume slider and "mute", volumes between 0..255 are valid.
 	// If you mute the volume, the returned main volume is 0.
@@ -92,6 +89,8 @@ public:
 	void            SetMainVolMute      (bool);
 	bool            GetMainVolMute      () const                            { return (GetMainVol()==0); }
 	void            ToggleMainVolMute   ()                                  { SetMainVolMute(!GetMainVolMute()); }
+	float           GetPrelistenGain    () const { return m_prelistenGain; }
+	void            SetPrelistenGain    (float);
 
 	// Goto specific tracks in the queue; if playing, this will stop the currently
 	// playing song and start the new one. If pause, this will stop the player.
@@ -112,8 +111,8 @@ public:
 	long            GetElapsedTime      ()          { long t1, t2, t3; GetTime(t1, t2, t3); return t2; }
 	long            GetRemainingTime    ()          { long t1, t2, t3; GetTime(t1, t2, t3); return t3; }
 	long            GetEnqueueTime      ();
-	void            SeekAbs             (long ms);
-	void            SeekRel             (long ms)   { SeekAbs(GetElapsedTime()+ms); }
+	void            Seek                (long ms);
+	void            SeekPrelisten       (long ms);
 
 	// Automatic volume
 	#define         SJ_AV_DEF_STATE             TRUE
@@ -130,6 +129,11 @@ public:
 	float           AvGetMaxGain        () const { return m_avMaxGain; }
 	float           AvGetCalculatedGain () const { return m_avCalculatedGain; } // this does not include the desired volume nor the max. gain!
 
+	// Equalizer
+	void            EqSetParam          (const bool* enabled, const SjEqParam*);
+	void            EqGetParam          (bool* e, SjEqParam* p) const { if(e){*e=m_eqEnabled;} if(p){*p=m_eqParam;} }
+	SjEqPresetFactory m_eqPresetFactory;
+
 	// Crossfade & Other fadings
 	void            SetAutoCrossfade    (bool e) { m_autoCrossfade=e; }
 	bool            GetAutoCrossfade    () const { return m_autoCrossfade; }
@@ -156,7 +160,7 @@ private:
 	// The player's backend, normally selected by a define as SJ_USE_GSTREAMER or SJ_USE_XINE
 	SjBackend*       m_backend;
 	SjBackendStream* m_streamA;
-	SjBackendStream* CreateStream       (const wxString& url, long seekMs, long fadeMs);
+	SjBackendStream* CreateStream       (const wxString& url, bool createPrelistenStream, long seekMs, long fadeMs);
 	void             DeleteStream       (SjBackendStream**, long fadeMs); // the given pointer must not be used by the caller after using this function!
 
 	#define          SJ_SYSVOL_DONTUSE  0
@@ -173,7 +177,15 @@ private:
 	#define          SJ_PL_DEFAULT   SJ_PL_MIX
 	long             m_prelistenDest;
 	SjBackend*       m_prelistenBackend;
+	SjBackendStream* m_prelistenStream;
 	long             m_prelistenUseSysVol;
+	float            m_prelistenGain;
+	#define          SJ_DEF_PL_MIX_QUIET 0.25
+	float            m_prelistenMixQuiet; // in mix mode, the normal channel is quieted by this gain
+	wxString         m_prelistenEqPreset;
+
+	// the trash
+	wxArrayPtrVoid   m_trashedStreams;
 
 	// tools
 	void            SendSignalToMainThread(int id, uintptr_t extraLong=0) const;
@@ -187,8 +199,6 @@ private:
 	bool            m_stopAfterThisTrack;
 	bool            m_stopAfterEachTrack;
 
-
-
 	// auto volume stuff
 	bool            m_avEnabled;
 	bool            m_avUseAlbumVol;
@@ -196,6 +206,11 @@ private:
 	float           m_avMaxGain;
 	float           m_avCalculatedGain;
 
+	// equalizer
+	#define         SJ_EQ_DEF_ENABLED     false
+	bool            m_eqEnabled;
+	SjEqParam       m_eqParam;
+
 	// crossfading etc.
 	#define         SJ_DEF_AUTO_CROSSFADE_ENABLED   true
 	bool            m_autoCrossfade;
