@@ -115,6 +115,7 @@ public:
 	wxString        GetCmdNameById      (int id, bool shortName=FALSE) { int index=CmdId2CmdIndex(id); if(index) { return GetCmdNameByIndex(index, shortName); } else { return wxEmptyString; } }
 
 	// misc. settings, public read
+	#define         SJ_ACCEL_ASK_ON_INTERRUPTING        0x00000001L
 	#define         SJ_ACCEL_CONTENT_DRAG               0x00000004L
 	#define         SJ_ACCEL_ASK_ON_MULTI_ENQUEUE       0x00000008L
 	#define         SJ_ACCEL_ASK_ON_CLEAR_PLAYLIST      0x00000010L
@@ -133,6 +134,7 @@ public:
 	#define         SJ_ACCEL_WHEEL_MODIFIER_AXIS_TOGGLE 0x00400000L
 	#define         SJ_ACCEL_WHEEL_RMOUSE_AXIS_TOGGLE   0x00800000L
 	#define         SJ_ACCEL_WHEEL_VALUE_INPUT          0x01000000L
+	#define         SJ_ACCEL_DCLICK_TOGGLE_VIEW         0x02000000L // deprecated
 	#define         SJ_ACCEL_DEFAULT                    0x0000FFFFL
 	long            m_flags;
 	long            m_selDragNDrop; // 0=off, 1=first click, 2=second click
