@@ -29,8 +29,10 @@
 #include <sjbase/base.h>
 #include <sjmodules/internalinterface.h>
 #include <sjmodules/basicsettings.h>
+#include <sjmodules/upnp.h>
 #include <sjmodules/scanner/folder_scanner.h>
 #include <sjmodules/scanner/server_scanner.h>
+#include <sjmodules/scanner/upnp_scanner.h>
 #include <sjmodules/library.h>
 #include <sjmodules/help/help.h>
 #include <sjmodules/settings.h>
@@ -40,6 +42,7 @@
 #include <sjmodules/arteditor.h>
 #include <sjmodules/mymusic.h>
 #include <sjmodules/playbacksettings.h>
+#include <sjmodules/fx/fx_settings.h>
 #include <sjmodules/vis/vis_module.h>
 #include <sjmodules/vis/vis_karaoke_module.h>
 #include <sjmodules/vis/vis_oscilloscope.h>
@@ -69,6 +72,7 @@ void SjInternalInterface::LoadModules(SjModuleList& list)
 	list.Append   (new SjMyMusicModule            (this));
 	list.Append   (new SjBasicSettingsModule      (this));
 	list.Append   (new SjPlaybackSettingsModule   (this));
+	list.Append   (new SjFxSettingsModule         (this));
 	list.Append   (new SjViewSettingsModule       (this));
 	list.Append   (new SjHelpModule               (this));
 	list.Append   (new SjArtEditorModule          (this));
@@ -76,10 +80,16 @@ void SjInternalInterface::LoadModules(SjModuleList& list)
 	list.Append   (new SjKioskModule              (this));
 	list.Append   (new SjAdvSearchModule          (this));
 	list.Append   (new SjVirtKeybdModule          (this));
+	#if SJ_USE_UPNP
+	list.Append   (new SjUpnpModule               (this));
+	#endif
 
 	// add MLR modules
 	list.Append   (new SjFolderScannerModule      (this));
 	list.Append   (new SjServerScannerModule      (this));
+	#if SJ_USE_UPNP
+	list.Append   (new SjUpnpScannerModule        (this));
+	#endif
 
 	// add COL modules
 	list.Append   (new SjLibraryModule            (this));
