@@ -137,7 +137,7 @@ BEGIN_EVENT_TABLE(SjMyMusicConfigPage, wxPanel)
 END_EVENT_TABLE()
 
 
-static int wxCALLBACK ListCtrlCompareFunction(long item1__, long item2__, long sortData)
+static int wxCALLBACK ListCtrlCompareFunction(wxIntPtr item1__, wxIntPtr item2__, wxIntPtr sortData)
 {
 	int                         ret = 0, toggleSort = sortData&0x00001000? 1 : 0;
 	SjSettingsSourceItem        *source1 = (SjSettingsSourceItem*)item1__,
@@ -190,38 +190,9 @@ wxPanel* SjMyMusicConfigPage::CreatePage(wxWindow* parent)
 	m_configMenuButton = new wxButton(page, IDC_IDXCONFIGSOURCEMENU, _("Options")+wxString(SJ_BUTTON_MENU_ARROW), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
 	buttonSizer->Add(m_configMenuButton, 0, wxLEFT|wxTOP|wxBOTTOM, SJ_DLG_SPACE);
 
-	m_updateButton = new wxButton(page, IDC_IDXUPDATEMENU, wxString::Format(wxT(" %s%s "), _("Update music library"), SJ_BUTTON_MENU_ARROW), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
+	m_updateButton = new wxButton(page, IDC_IDXUPDATEMENU, wxString::Format(" %s%s ", _("Update music library"), SJ_BUTTON_MENU_ARROW), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
 	buttonSizer->Add(m_updateButton, 0, wxALL, SJ_DLG_SPACE);
 
-	// add supported files hint
-	SjExtList supportedExt = g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_MUSICFILES); // equals to `g_mainFrame->m_player.GetExtList()`
-
-	wxArrayString arrayStr;
-	for( int i = supportedExt.GetCount()-1; i >= 0; i-- ) {
-		arrayStr.Add(supportedExt.GetExt(i));
-	}
-	arrayStr.Sort();
-
-	wxString line = _("Supported file types") + ": ", text, ext;
-	size_t i, i_cnt = arrayStr.GetCount();
-	bool hasMp3 = false, hasOgg = false;
-	for( i = 0; i < i_cnt; i++ )
-	{
-		ext = arrayStr.Item(i);
-		line += ext;
-		if( i != i_cnt-1 ) { line += ", "; }
-		if( line.Len() > 75 ) { if( text.Len() ) { text += "\n"; } text += line; line = ""; }
-		if( ext == "mp3" ) { hasMp3 = true; }
-		if( ext == "ogg" ) { hasOgg = true; }
-        if( hasMp3 && hasOgg && i != i_cnt-1 && i >= 70 ) { line += wxString::Format("%i", (int)(i_cnt-i-1)) + "  more"; break; }
-	}
-	if( line.Len() ) { if( text.Len() ) { text += "\n"; } text += line; }
-
-	staticText = new wxStaticText(page, -1, text);
-	sizer1->Add(staticText, 0, wxALL, SJ_DLG_SPACE);
-
-	sizer1->Add(1, SJ_DLG_SPACE); // some space
-
 	return page;
 }
 
@@ -274,7 +245,7 @@ SjMyMusicConfigPage::SjMyMusicConfigPage(SjMyMusicModule* myMusicModule, wxWindo
 	dialogSizer->SetSizeHints(this);
 
 	// init data
-	InitPage(g_tools->m_config->Read(wxT("settings/selSource"), wxT("")));
+	InitPage(g_tools->m_config->Read("settings/selSource", ""));
 }
 
 
@@ -306,7 +277,7 @@ void SjMyMusicConfigPage::UpdateButtons()
 
 	if( m_updateButton )
 	{
-		m_updateButton->SetLabel(wxString::Format(m_idxChanged? wxT("* %s%s") : wxT(" %s%s "), _("Update music library"), SJ_BUTTON_MENU_ARROW));
+		m_updateButton->SetLabel(wxString::Format(m_idxChanged? "* %s%s" : " %s%s ", _("Update music library"), SJ_BUTTON_MENU_ARROW));
 	}
 }
 
@@ -376,8 +347,7 @@ void SjMyMusicConfigPage::InitPage(const wxString& selSourceUrl)
 	// go through all search directories
 	SjSettingsSourceItem*           item;
 	SjSettingsSourceItemList::Node* itemnode = m_listOfSources.GetFirst();
-	int                             i = 0, new_i;
-	bool                            anythingSelected = FALSE;
+	int                             i = 0;
 	wxString                        sourceNotes;
 	while( itemnode )
 	{
@@ -388,39 +358,39 @@ void SjMyMusicConfigPage::InitPage(const wxString& selSourceUrl)
 		listitem.m_mask     = wxLIST_MASK_IMAGE | wxLIST_MASK_TEXT | wxLIST_MASK_DATA;
 		listitem.m_itemId   = i;
 		listitem.m_text     = item->GetUrl();
-		listitem.m_data     = (long)item;
+		listitem.SetData((void*)item);
 		listitem.m_image    = item->GetScannerModule()->GetSourceIcon(item->GetIndex());
 
 		sourceNotes = item->GetScannerModule()->GetSourceNotes(item->GetIndex());
 		if( !sourceNotes.IsEmpty() )
 		{
-			listitem.m_text.Append(wxT(" ("));
+			listitem.m_text.Append(" (");
 			listitem.m_text.Append(sourceNotes);
-			listitem.m_text.Append(wxT(')'));
+			listitem.m_text.Append(')');
 		}
 
-		new_i = m_listCtrl->InsertItem(listitem);
-
-		if( item->GetUrl() == selSourceUrl )
-		{
-			m_listCtrl->SetItemState(new_i, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
-			anythingSelected = TRUE;
-		}
+		m_listCtrl->InsertItem(listitem);
 
 		itemnode = itemnode->GetNext();
 		i++;
 	}
 
-	if( !anythingSelected && i > 0 )
-	{
-		m_listCtrl->SetItemState(0, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED,
-		                         wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
-	}
-
-	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol); // this may unselect Items on GTK, however, this should be fixed in wxWidgets/GTK
+	m_listCtrl->SortItems(ListCtrlCompareFunction, m_currSortCol);
 
 	m_listCtrl->Thaw();
 
+	// select the correct item
+	// (should be done after SortItems() on GTK this may remove the selection ...)
+	int i_cnt = m_listCtrl->GetItemCount();
+	for( i = 0; i < i_cnt; i ++ )
+	{
+		item = (SjSettingsSourceItem*)m_listCtrl->GetItemData(i);
+		if( item->GetUrl() == selSourceUrl ) {
+			m_listCtrl->SetItemState(i, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
+			break;
+		}
+	}
+
 	UpdateButtons();
 }
 
@@ -485,7 +455,7 @@ void SjMyMusicConfigPage::OnDelSource(wxCommandEvent& event)
 		SJ_WINDOW_DISABLER(SjDialog::FindTopLevel(this));
 		if( source->GetScannerModule()->DeleteSource(source->GetIndex(), SjDialog::FindTopLevel(this)) )
 		{
-			InitPage(wxT(""));
+			InitPage("");
 			m_idxChanged = TRUE;
 			UpdateButtons();
 		}
@@ -570,7 +540,7 @@ void SjMyMusicConfigPage::ShowContextMenu(wxWindow* window, const wxPoint& pt)
 			wxASSERT( scannerModule->m_addSourceTypes_.GetCount() == scannerModule->m_addSourceIcons_.GetCount() );
 			for( i = 0; i < scannerModule->m_addSourceTypes_.GetCount(); i++ )
 			{
-				m.Append(IDC_MODULE00+typeCount, scannerModule->m_addSourceTypes_.Item(i)+wxT("..."));
+				m.Append(IDC_MODULE00+typeCount, scannerModule->m_addSourceTypes_.Item(i)+"...");
 
 				typeCount++;
 			}
@@ -595,7 +565,7 @@ void SjMyMusicConfigPage::ShowContextMenu(wxWindow* window, const wxPoint& pt)
 
 		if( source )
 		{
-			m.Append(IDC_IDXCONFIGSOURCE, wxString::Format(_("Options for \"%s\""), SjTools::ShortenUrl(source->GetUrl()).c_str())+wxT("..."));
+			m.Append(IDC_IDXCONFIGSOURCE, wxString::Format(_("Options for \"%s\""), SjTools::ShortenUrl(source->GetUrl()).c_str())+"...");
 		}
 		else
 		{
@@ -640,7 +610,7 @@ void SjMyMusicConfigPage::OnUpdate(wxCommandEvent& event)
 SjMyMusicModule::SjMyMusicModule(SjInterfaceBase* interf)
 	: SjCommonModule(interf)
 {
-	m_file          = wxT("memory:mymusic.lib");
+	m_file          = "memory:mymusic.lib";
 	m_name          = _("Jukebox");
 	m_guiIcon          = SJ_ICON_MUSICLIB;
 	m_sort          = 10;
