@@ -88,7 +88,6 @@ private:
 	// common
 	SjSettingsModule* m_settingsModule;
 	bool            m_trackSelectionChanges;
-	void            OnCancel            (wxCommandEvent&);
 	void            OnOK                (wxCommandEvent&);
 	void            OnClose             (wxCloseEvent&);
 	void            OnOpenSettingsAsync (wxCommandEvent&);
@@ -100,7 +99,7 @@ private:
 BEGIN_EVENT_TABLE(SjSettingsDlg, SjDialog)
 	EVT_TOOL_RANGE              (1000, 2000,            SjSettingsDlg::OnSelectionChange    )
 	EVT_BUTTON                  (wxID_OK,               SjSettingsDlg::OnOK                 )
-	EVT_BUTTON                  (wxID_CANCEL,           SjSettingsDlg::OnCancel             )
+	EVT_BUTTON                  (wxID_CANCEL,           SjSettingsDlg::OnOK                 ) // sic! Close=Apply, Esc=Close => Esc=Apply
 	EVT_CLOSE                   (                       SjSettingsDlg::OnClose              )
 	EVT_MENU                    (IDO_OPENSETTINGSASYNC, SjSettingsDlg::OnOpenSettingsAsync  )
 END_EVENT_TABLE()
@@ -118,8 +117,6 @@ static SjSettingsDlg*    g_settingsDlg = NULL;
 SjSettingsDlg::SjSettingsDlg(SjSettingsModule* settingsModule, wxWindow* parent)
 	: SjDialog(parent, settingsModule->m_name, SJ_MODELESS, SJ_RESIZEABLE_IF_POSSIBLE)
 {
-	wxBusyCursor busyCursor;
-
 	g_settingsDlg       = this;
 	m_settingsModule    = settingsModule;
 
@@ -175,11 +172,8 @@ SjSettingsDlg::SjSettingsDlg(SjSettingsModule* settingsModule, wxWindow* parent)
 
 	m_pageSizer->Add(m_toolBar, 0, wxGROW);
 
-	m_buttonSizer = SjDialog::CreateButtons(this, SJ_DLG_OK_CANCEL);
-	m_dialogSizer->Add(m_buttonSizer,
-	                   0, wxGROW|wxLEFT|wxRIGHT, SJ_DLG_SPACE*2);
-
-	m_dialogSizer->Add(SJ_DLG_SPACE, SJ_DLG_SPACE);
+	m_buttonSizer = SjDialog::CreateButtons(this, SJ_DLG_OK, _("Close"));
+	m_dialogSizer->Add(m_buttonSizer, 0, wxGROW|wxALL, SJ_DLG_SPACE);
 
 	m_dialogSizer->SetSizeHints(this);
 
@@ -214,7 +208,7 @@ void SjSettingsDlg::LoadPage(const wxString& file, int index, int page__)
 		if( m_currPageModule )
 		{
 			m_currPageModule->m_notebookPage = GetNotebookPage();
-			m_currPageModule->DoneConfigPage(m_currPageWindow, SJ_CONFIGPAGE_DONE_GENERIC);
+			m_currPageModule->DoneConfigPage(m_currPageWindow, SJ_CONFIGPAGE_DONE_OK_CLICKED);
 			m_currPageModule->Unload();
 			m_currPageModule = NULL;
 		}
@@ -239,7 +233,7 @@ void SjSettingsDlg::LoadPage(const wxString& file, int index, int page__)
 					title.Append(m_currPageModule->m_name);
 					SetTitle(title);
 
-					m_pageSizer->Add(m_currPageWindow, 1, wxGROW|wxALL, SJ_DLG_SPACE);
+					m_pageSizer->Add(m_currPageWindow, 1, wxGROW, SJ_DLG_SPACE);
 					m_pageSizer->Layout();
 
 					// calculate the border size
@@ -264,27 +258,6 @@ void SjSettingsDlg::LoadPage(const wxString& file, int index, int page__)
 					}
 					SetSizeHints(minSize.x+borderSize.x, minSize.y+borderSize.y);
 
-					// set button texts
-					wxString okText, cancelText;
-					bool okBold;
-					m_currPageModule->GetConfigButtons(okText, cancelText, okBold);
-
-					wxButton* okButton = (wxButton*)FindWindow(wxID_OK);
-					if( okButton )
-					{
-						okButton->SetLabel(okText);
-
-						wxFont font = GetFont();
-						if( okBold ) font.SetWeight(wxBOLD);
-						okButton->SetFont(font);
-					}
-
-					wxButton* cancelButton = (wxButton*)FindWindow(wxID_CANCEL);
-					if( cancelButton )
-					{
-						cancelButton->SetLabel(cancelText);
-					}
-
 					// add a size event explicitly, the pages rely on this and it is not always send by wxWidgets (send on 2.x, not send on 3.x)
 					// note, that this event should be send _after_ the controls are layouted; normally, this should be the case here.
 					m_currPageWindow->GetEventHandler()->QueueEvent(new wxSizeEvent());
@@ -342,8 +315,6 @@ void SjSettingsDlg::SetSelToDialog(const wxString& selFile, int selIndex, int se
 {
 	m_trackSelectionChanges = FALSE;
 
-	//wxBusyCursor busy;
-
 	bool anythingSelected = false;
 	for( int i = 0; i < (int)m_toolBar->GetToolsCount(); i++ )
 	{
@@ -418,18 +389,6 @@ void SjSettingsDlg::OnSelectionChange(wxCommandEvent& event)
 }
 
 
-void SjSettingsDlg::OnCancel(wxCommandEvent&)
-{
-	if( m_currPageWindow && m_currPageModule )
-	{
-		m_currPageModule->DoneConfigPage(m_currPageWindow, SJ_CONFIGPAGE_DONE_CANCEL_CLICKED);
-	}
-
-	UnloadPage();
-	Destroy(); // do not used delete!
-}
-
-
 void SjSettingsDlg::OnOK(wxCommandEvent&)
 {
 	if( m_currPageWindow && m_currPageModule )
@@ -446,7 +405,7 @@ void SjSettingsDlg::OnOK(wxCommandEvent&)
 void SjSettingsDlg::OnClose(wxCloseEvent&)
 {
 	wxCommandEvent fwd;
-	OnCancel(fwd);
+	OnOK(fwd);
 }
 
 
