@@ -103,13 +103,16 @@ void SjModifyInfo::Delete(int i)
 }
 
 
-bool SjModifyInfo::LetConfirm(bool& askWriteId3, bool& askDelEmptyDir)
+bool SjModifyInfo::LetConfirm(bool& askWriteId3, bool& askDelEmptyDir, bool& onlyUrlsModified)
 {
 	bool letConfirm = FALSE;
 
+	askWriteId3 = FALSE;
+	askDelEmptyDir = FALSE;
+	onlyUrlsModified = TRUE;
+
 	long i, modCount = GetCount();
 	SjModifyItem* modItem;
-	wxString oldPath, newPath;
 	for( i = 0; i < modCount; i++ )
 	{
 		modItem = GetItem(i);
@@ -119,8 +122,8 @@ bool SjModifyInfo::LetConfirm(bool& askWriteId3, bool& askDelEmptyDir)
 			// if the url us modified, ask if to del. empty dir; this implies confirmation
 			if( !askDelEmptyDir )
 			{
-				SjTools::GetFileNameFromUrl(modItem->GetOldVal(), &oldPath);
-				SjTools::GetFileNameFromUrl(modItem->GetNewVal(), &newPath);
+				wxString oldPath = wxFileSystem::URLToFileName(modItem->GetOldVal()).GetPath(),
+				         newPath = wxFileSystem::URLToFileName(modItem->GetNewVal()).GetPath();
 				if( oldPath != newPath )
 				{
 					askDelEmptyDir = TRUE;
@@ -134,6 +137,7 @@ bool SjModifyInfo::LetConfirm(bool& askWriteId3, bool& askDelEmptyDir)
 			// if another field is modified, ask if to update the ID3 tags (only if confirmation
 			// is needed by other reasons, we do not want to pop up the confirmation window too often)
 			askWriteId3 = TRUE;
+			onlyUrlsModified = FALSE;
 		}
 
 		if( !letConfirm )
@@ -233,20 +237,42 @@ wxString SjModifyListCtrl::OnGetItemText(long index, long column) const
 
 	if( m_showUrlsOnly )
 	{
-		switch( column )
+		wxString text = column==CONFIRM_COL1_OLDURL? item->GetOldVal() : item->GetNewVal();
+		if( text.StartsWith("file:") )
 		{
-			case CONFIRM_COL1_OLDURL:   return item->GetOldVal();
-			default:                    return item->GetNewVal();
+			text = wxFileSystem::URLToFileName(text).GetFullPath();
 		}
+
+		return text;
 	}
 	else
 	{
 		switch( column )
 		{
-			case CONFIRM_COL2_FIELD:    return SjTrackInfo::GetFieldDescr(item->GetField());
-			case CONFIRM_COL2_OLDVAL:   return GetValDescr(item, FALSE);
-			case CONFIRM_COL2_NEWVAL:   return GetValDescr(item, TRUE);
-			default:                    if( m_items->IsFirstUrl(index) ) return item->GetUrl(); else return wxEmptyString;
+			case CONFIRM_COL2_FIELD:
+				return SjTrackInfo::GetFieldDescr(item->GetField());
+
+			case CONFIRM_COL2_OLDVAL:
+				return GetValDescr(item, FALSE);
+
+			case CONFIRM_COL2_NEWVAL:
+				return GetValDescr(item, TRUE);
+
+			default:
+				if( m_items->IsFirstUrl(index) )
+				{
+					wxString text = item->GetUrl();
+					if( text.StartsWith("file:") )
+					{
+						text = wxFileSystem::URLToFileName(text).GetFullPath();
+					}
+
+					return text;
+				}
+				else
+				{
+					return wxEmptyString;
+				}
 		}
 	}
 }
@@ -280,7 +306,7 @@ BEGIN_EVENT_TABLE(SjConfirmDlg, SjTagEditorPlugin)
 END_EVENT_TABLE()
 
 
-SjConfirmDlg::SjConfirmDlg(wxWindow* parent, SjModifyInfo& items, bool askWriteId3, bool askDelEmptyDir)
+SjConfirmDlg::SjConfirmDlg(wxWindow* parent, SjModifyInfo& items, bool askWriteId3, bool askDelEmptyDir, bool onlyUrlsModified)
 	: SjTagEditorPlugin(parent, wxT("confirm"), _("Confirm modifications"), NULL)
 {
 	m_items = &items;
@@ -294,7 +320,7 @@ SjConfirmDlg::SjConfirmDlg(wxWindow* parent, SjModifyInfo& items, bool askWriteI
 	m_msgTextCtrl = new wxStaticText(this, -1, GetMsg());
 	m_sizer1->Add(m_msgTextCtrl, 0, wxALL|wxGROW, SJ_DLG_SPACE);
 
-	m_listCtrl = new SjModifyListCtrl(this, IDC_CONFIRM_LIST, items, (askWriteId3==FALSE && askDelEmptyDir==TRUE));
+	m_listCtrl = new SjModifyListCtrl(this, IDC_CONFIRM_LIST, items, onlyUrlsModified);
 	m_sizer1->Add(m_listCtrl, 1, wxALL|wxGROW, SJ_DLG_SPACE);
 
 	wxBoxSizer* buttonSizer = new wxBoxSizer(wxHORIZONTAL);
@@ -326,7 +352,6 @@ SjConfirmDlg::SjConfirmDlg(wxWindow* parent, SjModifyInfo& items, bool askWriteI
 	okButton->SetDefault();
 
 	m_sizer1->SetSizeHints(this);
-	LoadSize();
 	m_listCtrl->SizeColumns();
 	CenterOnParent();
 }
@@ -352,8 +377,7 @@ void SjConfirmDlg::OnKeyDown(wxListEvent& event)
 		case WXK_DELETE:
 		case WXK_BACK:
 		{
-			wxCommandEvent fwd(wxEVT_COMMAND_MENU_SELECTED, IDC_CONFIRM_DELETE);
-			AddPendingEvent(fwd);
+			QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDC_CONFIRM_DELETE));
 		}
 		break;
 	}
@@ -371,7 +395,7 @@ void SjConfirmDlg::OnContextMenu(wxListEvent&)
 	m.Append(IDC_CONFIRM_DELETE, _("Delete"));
 	m.Enable(IDC_CONFIRM_DELETE, selItemCount>0);
 
-	PopupMenu(&m, ScreenToClient(::wxGetMousePosition()));
+	PopupMenu(&m);
 }
 
 
@@ -397,12 +421,25 @@ void SjConfirmDlg::OnEdit(wxCommandEvent&)
 			SjModifyItem* item = m_items->GetItem(index);
 			if( item )
 			{
-				wxTextEntryDialog textEntry(this, _("New value")+wxString(wxT(":")), SjTrackInfo::GetFieldDescr(item->GetField()), item->GetNewVal());
+				long field = item->GetField(); bool convertValToUrl = false;
+				wxString valInEdit = item->GetNewVal();
+				if( field == SJ_TI_URL && valInEdit.StartsWith("file:") )
+				{
+					valInEdit = wxFileSystem::URLToFileName(valInEdit).GetFullPath();
+					convertValToUrl = true;
+				}
+
+				wxTextEntryDialog textEntry(this, _("New value")+wxString(wxT(":")), SjTrackInfo::GetFieldDescr(field), valInEdit);
 				if( textEntry.ShowModal() == wxID_OK )
 				{
-					item->SetNewVal(textEntry.GetValue());
-					m_listCtrl->Refresh();
+					valInEdit = textEntry.GetValue();
+					if( convertValToUrl )
+					{
+						valInEdit = wxFileSystem::FileNameToURL(wxFileName(valInEdit));
+					}
 
+					item->SetNewVal(valInEdit);
+					m_listCtrl->Refresh();
 					m_itemsEdited = TRUE; // we have to check for void modifications on close
 				}
 			}
@@ -483,7 +520,7 @@ bool SjConfirmDlg::TransferDataFromWindow()
 		{
 			item = m_items->GetItem(i);
 			if(  item
-			        && !item->IsModified() )
+			 && !item->IsModified() )
 			{
 				m_items->Delete(i);
 				i--; // same index again
@@ -635,22 +672,6 @@ void SjTagEditorPlugin::AfterConstructor()
 	              0, wxGROW|wxALL, SJ_DLG_SPACE);
 
 	m_sizer1->SetSizeHints(this);
-	LoadSize();
 	CenterOnParent();
 }
 
-
-void SjTagEditorPlugin::LoadSize()
-{
-	wxRect r = g_tools->ReadRect(wxT("tageditor/")+m_name+wxT("Pos"));
-	SetSize(0, 0, r.width,  r.height);
-}
-
-
-void SjTagEditorPlugin::SaveSize()
-{
-	if( !IsMaximized() )
-	{
-		g_tools->WriteRect(wxT("tageditor/")+m_name+wxT("Pos"), GetRect());
-	}
-}
