@@ -340,7 +340,7 @@ END_EVENT_TABLE()
 SjKaraokeWindow::SjKaraokeWindow(SjKaraokeModule* karaokeModule, wxWindow* parent)
 	: wxWindow( parent, -1,
 	            wxPoint(-1000,-1000), wxSize(100,100),
-	            (wxNO_BORDER | wxFULL_REPAINT_ON_RESIZE ))
+	            (wxNO_BORDER | wxCLIP_CHILDREN | wxFULL_REPAINT_ON_RESIZE ))
 {
 	m_karaokeModule     = karaokeModule;
 
@@ -403,6 +403,10 @@ void SjKaraokeWindow::OnTimer(wxTimerEvent&)
 	if( m_inPaint ) return;
 	m_inPaint = true;
 
+	#ifdef __WXMAC__
+	m_pleaseUpdateAll = true; // partly updates do not work well on Mac OS X
+	#endif
+
 	// does the size of the window have changed?
 	if( m_clientSize != GetClientSize() || m_bgChanged )
 	{
