@@ -50,6 +50,8 @@ public:
 	void            OnMenuOption        (int);
 	void            PleaseUpdateSize    (SjVisWindow*);
 	void            AddVisData          (const float* buffer, long bytes);
+	wxWindow*       GetSuitableParentForOverlay() { return (wxWindow*)m_oscWindow; }
+
 private:
 	SjOscWindow*    m_oscWindow;
 	SjVisWindow*    m_impl;
@@ -60,6 +62,7 @@ private:
 	wxString        m_leadArtistName;
 	#define         SJ_OSC_SHOW_SPECTRUM    0x00000001L
 	#define         SJ_OSC_SHOW_OSC         0x00000002L
+	#define         SJ_OSC_MONO_CHANNEL     0x00010000L
 	#define         SJ_OSC_SHOW_STARFIELD   0x00040000L
 	#define         SJ_OSC_SHOW_FIGURES     0x00080000L
 	#define         SJ_OSC_SHOW_DEFAULT     0x0000FFFFL
