@@ -19,9 +19,15 @@
  *
  *******************************************************************************
  *
- * File:    dialogsj.cpp
+ * File:    dialog.cpp
  * Authors: Björn Petersen
  * Purpose: Dialog base-classes
+  *
+ *******************************************************************************
+ *
+ * NB: We avoid disable non-exitable controls as wxStaticText as this may look
+ * ugly on some OS (OS X, some Windows versions).  Moreover, this also may saves
+ * complexity esp. for nested check boxes.
  *
  ******************************************************************************/
 
@@ -106,7 +112,7 @@ wxSizer* SjDialog::CreateButtons(wxWindow* this_, long flags,
 
 		b = new wxButton(this_, IDC_NEXTDLGPAGE, wxT(">>"), wxDefaultPosition,  wxSize(BUTTON_W, -1));
 		if( !nextTitle.IsEmpty() ) { b->SetToolTip(nextTitle); }
-		buttonSizer->Add(b, 0, wxRIGHT, SJ_DLG_SPACE);
+		buttonSizer->Add(b, 0, wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
 	}
 
 	buttonSizer->Add(1,
@@ -116,13 +122,13 @@ wxSizer* SjDialog::CreateButtons(wxWindow* this_, long flags,
 	if( flags & SJ_DLG_OK )
 	{
 		buttonDefault = new wxButton(this_, wxID_OK, okTitle.IsEmpty()? wxString(_("OK")) : okTitle);
-		buttonSizer->Add(buttonDefault, 0, 0, SJ_DLG_SPACE);
+		buttonSizer->Add(buttonDefault, 0, wxBOTTOM, SJ_DLG_SPACE);
 	}
 
 	if( flags & SJ_DLG_CANCEL )
 	{
 		b = new wxButton(this_, wxID_CANCEL,  cancelTitle.IsEmpty()? wxString(_("Cancel")) : cancelTitle);
-		buttonSizer->Add(b, 0, wxLEFT, SJ_DLG_SPACE);
+		buttonSizer->Add(b, 0, wxLEFT|wxBOTTOM, SJ_DLG_SPACE);
 	}
 
 	// finally, set the default button. do it last to avoid
@@ -321,7 +327,6 @@ wxWindow* SjDialog::GetSuitableDlgParent()
 
 void SjDialog::PleaseRestartMsg(wxWindow* parent)
 {
-	wxWindowDisabler disabler(FindTopLevel(parent));
 	SjMessageBox(wxString::Format(_("Please restart %s so that the changes can take effect."), SJ_PROGRAM_NAME),
 	             SJ_PROGRAM_NAME, wxOK|wxICON_INFORMATION, FindTopLevel(parent));
 }
@@ -458,64 +463,6 @@ void SjDialog::AddState(const wxString& label, int id, const wxString& value)
 }
 
 
-SjDialogPos::SjDialogPos(const wxString& regKey)
-{
-	m_regKey = regKey;
-	m_forDisplay = wxNOT_FOUND;
-}
-
-
-void SjDialogPos::Save(wxTopLevelWindow* dlg)
-{
-	if( !dlg->IsMaximized() && !dlg->IsIconized() )
-	{
-		m_rect = dlg->GetRect();
-
-		m_forDisplay = wxDisplay::GetFromWindow(g_mainFrame);
-		if( m_forDisplay != wxNOT_FOUND )
-		{
-			wxDisplay display(m_forDisplay);
-			m_forDisplayGeometry = display.GetGeometry();
-		}
-
-		g_tools->WriteRect(m_regKey, m_rect);
-	}
-}
-
-
-void SjDialogPos::Restore(wxTopLevelWindow* dlg)
-{
-	wxRect storedRect = g_tools->ReadRect(m_regKey);
-
-	// set width and height
-	if( storedRect.width > 0 && storedRect.width < 5000
-	        && storedRect.height > 0 && storedRect.height < 5000 )
-	{
-		dlg->SetSize(0, 0, storedRect.width,  storedRect.height);
-	}
-
-	// set the position if the main frame is still on the same display
-	int forDisplay = wxDisplay::GetFromWindow(g_mainFrame);
-	wxRect forDisplayGeometry;
-	if( forDisplay != wxNOT_FOUND )
-	{
-		wxDisplay display(forDisplay);
-		forDisplayGeometry = display.GetGeometry();
-	}
-
-	if( forDisplay != wxNOT_FOUND
-	        && forDisplay == m_forDisplay
-	        && forDisplayGeometry == m_forDisplayGeometry )
-	{
-		dlg->SetSize(storedRect.x, storedRect.y, -1, -1, wxSIZE_USE_EXISTING);
-	}
-	else
-	{
-		dlg->CentreOnParent();
-	}
-}
-
-
 /*******************************************************************************
  * SjDlgCheckCtrl class - a check box plus a control
  ******************************************************************************/
@@ -525,7 +472,6 @@ SjDlgCheckCtrl::SjDlgCheckCtrl()
 {
 	m_checkBox  = NULL;
 	m_spinCtrl  = NULL;
-	m_staticText= NULL;
 }
 
 
@@ -569,9 +515,7 @@ void SjDlgCheckCtrl::Create(wxWindow* parentWindow, wxSizer* parentSizer,
 	                            ctrlMin, ctrlMax, intCtrlVal);
 	m_sizer->Add(m_spinCtrl, 0, wxALIGN_CENTER_VERTICAL|wxLEFT|wxRIGHT, SJ_DLG_SPACE);
 
-	m_staticText = new wxStaticText(parentWindow, -1,
-	                                text.AfterFirst('%').Mid(1).Trim(FALSE));
-	m_sizer->Add(m_staticText, 0, wxALIGN_CENTER_VERTICAL);
+	m_sizer->Add(new wxStaticText(parentWindow, -1, text.AfterFirst('%').Mid(1).Trim(FALSE)), 0, wxALIGN_CENTER_VERTICAL);
 }
 
 
@@ -579,7 +523,7 @@ void SjDlgCheckCtrl::Enable(bool enable)
 {
 	if( m_checkBox )
 	{
-		wxASSERT( m_spinCtrl && m_checkBox && m_staticText );
+		wxASSERT( m_spinCtrl && m_checkBox );
 
 		if( enable )
 		{
@@ -598,7 +542,6 @@ void SjDlgCheckCtrl::Enable(bool enable)
 
 		m_checkBox->Enable(enable);
 		m_spinCtrl->Enable(enable&&m_checkBox->IsChecked());
-		m_staticText->Enable(enable);
 	}
 }
 
@@ -885,7 +828,7 @@ long SjDlgControls::GetValueLong(long index)  const
 {
 	wxString valueStr = GetValue(index);
 	long valueLong;
-	valueStr.ToLong(&valueLong);
+	if( !valueStr.ToLong(&valueLong) ) { valueLong = 0; }
 	return valueLong;
 }
 
@@ -910,7 +853,7 @@ void SjDlgControls::SetValue(long index, const wxString& value)
 	if( dc.m_wndCtrl )
 	{
 		long valueLong;
-		value.ToLong(&valueLong);
+		if( !value.ToLong(&valueLong) ) { valueLong = 0; }
 
 		if( dc.m_type == SJ_DLG_TEXTCTRL_TYPE )
 		{
@@ -956,16 +899,16 @@ long SjDlgControls::Render(wxWindow* parent, wxSizer* parentSizer, int idButtons
 	if( iCount )
 	{
 		wxGridBagSizer* gbsizer = new wxGridBagSizer(SJ_DLG_SPACE/2, SJ_DLG_SPACE);
-		gbsizer->AddGrowableCol(1);
 		parentSizer->Add(gbsizer, 0, wxALL|wxGROW, SJ_DLG_SPACE);
 
 		int posY = 0;
+		bool growableColSet = false;
 		for( index = 0; index < iCount; index++ )
 		{
 			SjDlgCtrl& dc = m_ctrl[index];
 
 			long valueLong;
-			dc.m_value.ToLong(&valueLong);
+			if( !dc.m_value.ToLong(&valueLong) ) { valueLong = 0; }
 
 			// create control
 			bool hasLabel = true;
@@ -1036,7 +979,17 @@ long SjDlgControls::Render(wxWindow* parent, wxSizer* parentSizer, int idButtons
 			gbsizer->Add(dc.m_wndCtrl, 0, wxALIGN_CENTER_VERTICAL|controlSizeStyle);
 			gbsizer->SetItemPosition(dc.m_wndCtrl, wxGBPosition(posY, hasLabel?1:0));
 			if( !hasLabel )
+			{
 				gbsizer->SetItemSpan(dc.m_wndCtrl, wxGBSpan(1, 2));
+			}
+			else
+			{
+				if( !growableColSet )
+				{
+					gbsizer->AddGrowableCol(1);
+					growableColSet = true;
+				}
+			}
 
 			posY ++;
 		}
@@ -1065,8 +1018,6 @@ void SjDlgControls::Enable(bool enable)
 	for( index = 0; index < iCount; index++ )
 	{
 		SjDlgCtrl& dc = m_ctrl[index];
-		if( dc.m_wndLabel )
-			dc.m_wndLabel->Enable(enable);
 
 		if( dc.m_wndCtrl )
 			dc.m_wndCtrl->Enable(enable);
