@@ -35,6 +35,7 @@
 #include <sjtools/gcalloc.h>
 #if SJ_USE_SCRIPTS
 
+
 #define GcADR uintptr_t
 
 
@@ -122,7 +123,7 @@ void* SjGcAlloc(unsigned long size, long flags,
 }
 
 
-#ifdef __WXDEBUG__ // currently not needed
+#if 0 // currently not needed
 void SjGcRef(void* ptr)
 {
 	wxASSERT( wxThread::IsMain() );
@@ -172,7 +173,6 @@ void SjGcUnref(void* ptr)
 }
 
 
-#ifdef __WXDEBUG__
 bool SjGcIsValidPtr(void* ptr)
 {
 	wxASSERT( wxThread::IsMain() );
@@ -183,10 +183,9 @@ bool SjGcIsValidPtr(void* ptr)
 	CHECK_BLOCK( block );
 	return true;
 }
-#endif
 
 
-#ifdef __WXDEBUG__
+#if 0
 bool SjGcHasStaticRef(void* ptr)
 {
 	wxASSERT( wxThread::IsMain() );
@@ -239,10 +238,8 @@ void SjGcShutdown()
  ******************************************************************************/
 
 
-static GcADR s_gc_minAdr, s_gc_maxAdr, s_gc_noPtrMask, *s_gc_allAdr = NULL, s_gc_allAdrCount;
-#ifdef __WXDEBUG__
+static GcADR s_gc_minAdr, s_gc_maxAdr, *s_gc_allAdr = NULL, s_gc_allAdrCount;
 static long s_infoAssumedPointers, s_infoPointersFollowed;
-#endif
 
 
 static void SjGcSweep(GcBlock* block)
@@ -270,12 +267,9 @@ static void SjGcSweep(GcBlock* block)
 		adr = *dataPtr;
 
 		if(  adr >= s_gc_minAdr
-		        &&  adr <= s_gc_maxAdr
-		        && (adr & s_gc_noPtrMask) == 0 )
+		 &&  adr <= s_gc_maxAdr )
 		{
-			#ifdef __WXDEBUG__
-				s_infoAssumedPointers ++;
-			#endif
+			s_infoAssumedPointers ++;
 
 			// binary search for adr in s_gc_allAdr
 			left = 0; right = s_gc_allAdrCount - 1;
@@ -298,9 +292,7 @@ static void SjGcSweep(GcBlock* block)
 					        /*&& cur2->references -- no needed, only blocks with referenced are added to s_gc_allAdr[]*/ )
 					{
 						// pointer found!
-						#ifdef __WXDEBUG__
-							s_infoPointersFollowed ++;
-						#endif
+						s_infoPointersFollowed ++;
 						SjGcSweep(cur2);
 					}
 					break;
@@ -320,9 +312,7 @@ static void SjGcSweep(GcBlock* block)
 								&&  cur2->references/*in contras to the binary search above, this comparison is needed here!*/ )
 						{
 							// pointer found!
-							#ifdef __WXDEBUG__
-								s_infoPointersFollowed ++;
-							#endif
+							s_infoPointersFollowed ++;
 							SjGcSweep(cur2);
 						}
 						break;
@@ -340,7 +330,10 @@ static void SjGcSweep(GcBlock* block)
 
 static int compareAdr(const void *arg1, const void *arg2)
 {
-	return *((GcADR*)arg1) - *((GcADR*)arg2);
+	// CAVE: do not use arg1-arg2 as the pointer may be 64bit and the return value may be 32bit only...
+	if( *((GcADR*)arg1) < *((GcADR*)arg2) ) return -1;
+	if( *((GcADR*)arg1) > *((GcADR*)arg2) ) return  1;
+	return 0;
 }
 
 
@@ -371,7 +364,6 @@ void SjGcDoCleanup()
 
 		s_gc_minAdr         = 0; // initialize, we may get a s_gc_allAdrCount==0 after this part and the initialization with s_gc_allAdr[0] below will not be done
 		s_gc_maxAdr         = 0; //     - " -
-		s_gc_noPtrMask      = 0;
 
 		wxASSERT( s_gc_allAdr == NULL );
 		s_gc_allAdr         = (GcADR*)malloc(g_gc_system.curBlockCount*sizeof(GcADR));
@@ -388,52 +380,33 @@ void SjGcDoCleanup()
 			{
 				adr = ((GcADR)curBlock) + sizeof(GcBlock);
 
-				#ifdef __WXDEBUG__
-					if( s_gc_minAdr == 0 || adr < s_gc_minAdr )
-						s_gc_minAdr = adr;
-
-					if( s_gc_maxAdr == 0 || adr > s_gc_maxAdr )
-						s_gc_maxAdr = adr;
-				#endif
-
-				s_gc_noPtrMask |= adr;
-
 				s_gc_allAdr[s_gc_allAdrCount++] = adr;
 			}
 
 			// next block
 			curBlock = curBlock->next;
 		}
-
-		s_gc_noPtrMask &= ~0xFFFFFFFFL;
 	}
 
 	if( s_gc_allAdrCount )
 	{
 		qsort(s_gc_allAdr, s_gc_allAdrCount, sizeof(GcADR), compareAdr);
 
-		#ifdef __WXDEBUG__
-			wxASSERT( s_gc_minAdr == s_gc_allAdr[0] );
-			wxASSERT( s_gc_maxAdr == s_gc_allAdr[s_gc_allAdrCount-1] );
-		#endif
-
 		s_gc_minAdr = s_gc_allAdr[0];
 		s_gc_maxAdr = s_gc_allAdr[s_gc_allAdrCount-1];
 	}
 
 	// start scanning with the only blocks used directly
 	// (there may be zero used blocks, however, continue anyway as some blocks may be freed)
-	#ifdef __WXDEBUG__
-		s_infoAssumedPointers = 0;
-		s_infoPointersFollowed = 0;
-	#endif
+	s_infoAssumedPointers = 0;
+	s_infoPointersFollowed = 0;
 	curBlock = s_gc_firstBlock;
 	while( curBlock )
 	{
 		CHECK_BLOCK( curBlock );
 
 		if(  curBlock->references >= 2 /* static? */
-		        && !curBlock->oneRefValidated /* the flag may change for any block in SjGcSweep() */)
+		 && !curBlock->oneRefValidated /* the flag may change for any block in SjGcSweep() */)
 		{
 			SjGcSweep(curBlock);
 		}
@@ -496,20 +469,43 @@ void SjGcDoCleanup()
 	}
 
 	// integry check
-	#ifdef __WXDEBUG__
+	if( g_debug )
+	{
+		// compile time assumptions, see remark (*) in gcalloc.h
+		// (in SjGcSweep() we only check for pointers on multiple of sizeof(void*))
+		struct just_a_test {
+			void* ptr0;
+			char  force_unaligned1;
+			void* ptr2;
+			short force_unaligned3;
+			void* ptr4;
+			int   force_unaligned5;
+			void* ptr6;
+			long  force_unaligned7;
+			void* ptr8;
+		};
+
+		just_a_test* test = (just_a_test*)malloc(sizeof(just_a_test));
+			wxASSERT( sizeof(just_a_test) == 9*sizeof(void*) );
+			wxASSERT( &test->ptr0 == (void*)(((char*)test)+sizeof(void*)*0) );
+			wxASSERT( &test->ptr2 == (void*)(((char*)test)+sizeof(void*)*2) );
+			wxASSERT( &test->ptr4 == (void*)(((char*)test)+sizeof(void*)*4) );
+			wxASSERT( &test->ptr6 == (void*)(((char*)test)+sizeof(void*)*6) );
+			wxASSERT( &test->ptr8 == (void*)(((char*)test)+sizeof(void*)*8) );
+		free(test);
+
+		// runtime checks
+		unsigned long cnt = 0, cntBytes = 0;
+		GcBlock* iter = s_gc_firstBlock;
+		while( iter )
 		{
-			unsigned long cnt = 0, cntBytes = 0;
-			GcBlock* iter = s_gc_firstBlock;
-			while( iter )
-			{
-				cnt++;
-				cntBytes += iter->size;
-				iter = iter->next;
-			}
-			wxASSERT( cnt == g_gc_system.curBlockCount );
-			wxASSERT( cntBytes == g_gc_system.curSize );
+			cnt++;
+			cntBytes += iter->size;
+			iter = iter->next;
 		}
-	#endif
+		wxASSERT( cnt == g_gc_system.curBlockCount );
+		wxASSERT( cntBytes == g_gc_system.curSize );
+	}
 
 	// done
 	wxASSERT( infoOldSize-g_gc_system.curSize == infoBytesFreed );
@@ -517,19 +513,17 @@ void SjGcDoCleanup()
 	g_gc_system.sizeChangeSinceLastCleanup = 0;
 	g_gc_system.lastCleanupTimestamp = SjTools::GetMsTicks();
 
-	#ifdef __WXDEBUG__
-		wxLogDebug( wxT("%i/%i/%i possible/assumed/followed pointers [gc]"),
-					(int)(infoOldSize/sizeof(GcADR)), (int)s_infoAssumedPointers, (int)s_infoPointersFollowed
-				  );
-
-		wxLogDebug( wxT("%i ms needed to free %iK of %iK (%i of %i blocks) [gc]"),
+	if( g_debug&0x04 /*4=additional script debugging, see user-guide*/ )
+	{
+		wxLogInfo ( "%i ms needed to free %iK of %iK (%i of %i blocks, %i/%i/%i possible/assumed/followed pointers) [gc]",
 					(int)(g_gc_system.lastCleanupTimestamp-infoCleanupStartTimestamp),
 					(int)(infoBytesFreed/1024),
 					(int)(infoOldSize/1024),
 					(int)infoBlocksFreed,
-					(int)infoOldBlockCount
+					(int)infoOldBlockCount,
+					(int)(infoOldSize/sizeof(GcADR)), (int)s_infoAssumedPointers, (int)s_infoPointersFollowed
 				  );
-	#endif
+	}
 }
 
 
