@@ -69,7 +69,6 @@ void SjTestdrive1()
 	 * LOGICAL TESTS
 	 ******************************************************************************/
 
-
 	/* older versions of wxWidgets are incompatible (in fact, the wxWidgets interface has changed) */
 	#if !wxCHECK_VERSION(2, 8, 0)
 		#error at least wxWidgets 2.8 required
@@ -85,20 +84,12 @@ void SjTestdrive1()
 		wxLogWarning(wxT("Testdrive: wxString::Replace() may get some optimizations"));
 	#endif
 
-	/* Debug-versions without Beta-code are suspicious */
-	#if !defined(SJ_BETA) && defined(__WXDEBUG__)
-		wxLogWarning(wxT("Testdrive: Debug versions without beta code are suspicious."));
-	#endif
-
 
 	/*******************************************************************************
 	 * PHYSICAL TESTS
 	 ******************************************************************************/
 
-
-	#ifdef SJ_BETA // (***)
-
-	wxLogInfo(wxT("Testdrive: Some physical tests (beta only) ..."));
+	wxLogInfo(wxT("Testdrive: Some physical tests ..."));
 
 	/* Test SjTools::AreFilesSame() */
 	{
@@ -194,6 +185,7 @@ void SjTestdrive1()
         wxASSERT(r==NULL);
 	}
 
+
 	/* test SjStringSerializer
 	*/
 	{
@@ -222,6 +214,25 @@ void SjTestdrive1()
 		}
 	}
 
+
+	/* test various string functions
+	*/
+	{
+		wxASSERT( SjTools::EnsureTrailingSlash("/test")  == "/test/" );
+		wxASSERT( SjTools::EnsureTrailingSlash("/test/") == "/test/" );
+		#ifdef __WXMSW__
+			wxASSERT( SjTools::EnsureTrailingSlash("\\test")  == "\\test\\" );
+			wxASSERT( SjTools::EnsureTrailingSlash("\\/test") == "\\/test/" );
+			wxASSERT( SjTools::EnsureTrailingSlash("/\\test") == "/\\test/" );
+		#endif
+
+		wxASSERT( SjTools::VersionString2Long("1.2.3")  == 0x01020300 );
+		wxASSERT( SjTools::VersionString2Long("10.11")  == 0x0A0B0000 );
+		wxASSERT( SjTools::VersionString2Long("20")     == 0x14000000 );
+		wxASSERT( SjTools::VersionString2Long("15.10.3")== 0x0F0A0300 );
+	}
+
+
 	/* make sure, SjSLHash, SjSSHash are case-sensitibe while SjExtList is not (important eg. to allow exentensions as "MP3" on linux)
 	*/
 	{
@@ -261,11 +272,12 @@ void SjTestdrive1()
 	eg. by wxFileSystem::FileNameToURL()  */
 	{
 		// create a file with a "#" in its name using wxFile
-		wxString name = wxT("test #1 100% hard.test");
+		wxString name = wxT("test #1 100% hard '\xE4\xF6\xFC\xC4\xD6\xDC\xDF'.test");
 		wxString content = wxT("test content");
 		wxString path = CreateTestFileUsingWxFile(name, content);
 
 		// try to open this file using wxFileSystem
+		{
 		wxString pathAsUrl = wxFileSystem::FileNameToURL(path); // pathAsUrl should be file:/tmp/test %231 100%25 hard.test
 		wxFileSystem fs;
 		wxFSFile* fsFile = fs.OpenFile(pathAsUrl);
@@ -292,6 +304,70 @@ void SjTestdrive1()
 		{
 			wxLogWarning(wxT("Testdrive: wxFileSystem failed: Cannot open %s."), path.c_str());
 		}
+		}
+
+
+		// check if we can read the file using wxFileSystem::FindFirst()
+		{
+			wxFileName fn(path); // check wxFileName to work with FILEs
+			if(  path.Left(5)=="file:" ) { wxLogWarning("Testdrive: fn should not start with 'file:'"); }
+			if( !fn.IsOk()             ) { wxLogWarning("Testdrive: fn.IsOk() failed"); }
+			if(  fn.IsDir()            ) { wxLogWarning("Testdrive: fn.IsDir() failed"); }
+			if( !fn.FileExists()       ) { wxLogWarning("Testdrive: fn.FileExists() failed"); }
+			if( !fn.DirExists()        ) { wxLogWarning("Testdrive: fn.DirExists() failed"); } // Notice that this function tests the directory part of this object, i.e. the string returned by GetPath(), and not the full path returned by GetFullPath().
+
+			wxString fn2DirStr = fn.GetPath(wxPATH_GET_SEPARATOR);
+			if(  fn2DirStr.Left(5)=="file:" ) { wxLogWarning("Testdrive: fn2DirStr should not start with 'file:'"); }
+			if(  fn2DirStr.Last()!='/' && fn2DirStr.Last()!='\\' ) { wxLogWarning("Testdrive: fn2DirStr: Where is the trailing slash?"); }
+			wxFileName fn2(fn2DirStr);  // the wxFileName constructor creates DIRs without FILEs if there is a trailing slash!s
+			if( !fn2.IsOk() )       { wxLogWarning("Testdrive: fn2.IsOk() failed"); }
+			if( !fn2.IsDir() )      { wxLogWarning("Testdrive: fn2.IsDir() failed"); }
+			if(  fn2.FileExists() ) { wxLogWarning("Testdrive: fn2.FileExists() failed"); }
+			if( !fn2.DirExists() )  { wxLogWarning("Testdrive: fn2.DirExists() failed"); }
+
+			// create filesystem object and let if point to the given directory
+			wxFileSystem fs;
+			wxString locationUrl = wxFileSystem::FileNameToURL(fn2DirStr);
+			if( fn2DirStr.Left(5) == "file:" ) { wxLogWarning("Testdrive: fn2DirStr should not start with 'file:'"); }
+			if( locationUrl.Left(5) != "file:" ) { wxLogWarning("Testdrive: locationUrl should start with 'file:'"); }
+			fs.ChangePathTo(locationUrl, true);
+			wxString pathChangedTo = fs.GetPath();
+			if( pathChangedTo.Left(5) != "file:" ) { wxLogWarning("Testdrive: pathChangedTo should start with 'file:'"); }
+
+			// search for all files in the given directory
+			bool testFileFound = false;
+			wxString dirEntryLocationUrl = fs.FindFirst("*", wxFILE);
+			while( !dirEntryLocationUrl.IsEmpty() )
+			{
+				if( dirEntryLocationUrl.Left(5) != "file:" ) { wxLogWarning("Testdrive: dirEntryLocationUrl should start with 'file:'"); }
+
+				wxFileName dirEntryFileName = wxFileSystem::URLToFileName(dirEntryLocationUrl);
+				if( !dirEntryFileName.IsOk()       ) { wxLogWarning("Testdrive: dirEntryFileName.IsOk() failed"); }
+				if(  dirEntryFileName.IsDir()      ) { wxLogWarning("Testdrive: dirEntryFileName.IsDir() failed"); } // we use wxFILE in FindFirst(), there should be no directories!
+				if( !dirEntryFileName.FileExists() ) { wxLogWarning("Testdrive: dirEntryFileName.FileExists() failed"); }
+				if( !dirEntryFileName.DirExists()  ) { wxLogWarning("Testdrive: dirEntryFileName.DirExists() failed"); }
+
+				wxString dirEntryFileNameFullPathStr = dirEntryFileName.GetFullPath();
+				if( dirEntryFileNameFullPathStr.Left(5) == "file:" ) { wxLogWarning("Testdrive: dirEntryFileNameFullPathStr should start with 'file:'"); }
+
+				wxString dirEntryFileNameFullNameStr = dirEntryFileName.GetFullName();
+				if( dirEntryFileNameFullNameStr.Left(5) == "file:" ) { wxLogWarning("Testdrive: dirEntryFileNameFullNameStr should start with 'file:'"); }
+				if( dirEntryFileNameFullNameStr == name )
+				{
+					testFileFound = true;
+				}
+
+				dirEntryLocationUrl = fs.FindNext();
+			}
+
+			if( !testFileFound ) { wxLogWarning("Testdrive: Testfile not found using wxFileSystem::Find*()"); }
+
+			// finally check, if the second parameter (dir/file indicator works as expected)
+			wxString locationUrl2 = wxFileSystem::FileNameToURL(path);
+			fs.ChangePathTo(locationUrl2, false);
+			wxString pathChangedTo2 = fs.GetPath();
+			wxASSERT( pathChangedTo.Lower() == pathChangedTo2.Lower() ); // under Windows, there may differences regarding the case of the volume, so test case-insensitive ...
+		}
 
 		// done.
 		::wxRemoveFile(path);
@@ -299,65 +375,64 @@ void SjTestdrive1()
 		// another test checking the "dirExists" stuff:
 		// since wx2.8, fileName.DirExists() checks if the base dir exists, not if the file is a directory!
 		// (internally, wxFileName::DirExists(GetPath()) is called, for  wx2.6 internally, wxFileName::DirExists(GetFullPath()) was called)
-		#define FILE_ASSERT(c) if( !(c) ) { wxLogWarning(wxT("Testdrive: ") wxT(#c) wxT(" failed for %s"), path.c_str()); }
 		{
 			wxString path = SjTools::GetSilverjukeProgramDir();                             // existant dir
 			wxFileName filename(path);
-			FILE_ASSERT     (  filename.IsDir() );
-			FILE_ASSERT     (  filename.DirExists() );
-			FILE_ASSERT     (  wxFileName::DirExists(path) );
-			FILE_ASSERT     (  ::wxDirExists(path) );
-			FILE_ASSERT     ( !filename.FileExists() );
-			FILE_ASSERT     ( !::wxFileName::FileExists(path) );
-			FILE_ASSERT     ( !::wxFileExists(path) );
+			wxASSERT(  filename.IsDir() );
+			wxASSERT(  filename.DirExists() );
+			wxASSERT(  wxFileName::DirExists(path) );
+			wxASSERT(  ::wxDirExists(path) );
+			wxASSERT( !filename.FileExists() );
+			wxASSERT( !::wxFileName::FileExists(path) );
+			wxASSERT( !::wxFileExists(path) );
 		}
 		{
 			wxString path = SjTools::GetSilverjukeProgramDir() + wxT("Silverjuke.exe");     // existant file in existant dir - do not run this test if the program has not the name "silverjuke.exe"
 			if( ::wxFileExists(path) ) {
 				wxFileName filename(path);
-				FILE_ASSERT     ( !filename.IsDir() );
-				FILE_ASSERT     (  filename.DirExists() );
-				FILE_ASSERT     ( !wxFileName::DirExists(path) );
-				FILE_ASSERT     ( !::wxDirExists(path) );
-				FILE_ASSERT     (  filename.FileExists() );
-				FILE_ASSERT     (  ::wxFileName::FileExists(path) );
-				FILE_ASSERT     (  ::wxFileExists(path) );
+				wxASSERT( !filename.IsDir() );
+				wxASSERT(  filename.DirExists() );
+				wxASSERT( !wxFileName::DirExists(path) );
+				wxASSERT( !::wxDirExists(path) );
+				wxASSERT(  filename.FileExists() );
+				wxASSERT(  ::wxFileName::FileExists(path) );
+				wxASSERT(  ::wxFileExists(path) );
 			}
 		}
 		{
 			wxString path = SjTools::GetSilverjukeProgramDir() + wxT("unexistant.file");    // unexistant file in existant dir
 			wxFileName filename(path);
-			FILE_ASSERT     ( !filename.IsDir() );
-			FILE_ASSERT     (  filename.DirExists() );
-			FILE_ASSERT     ( !wxFileName::DirExists(path) );
-			FILE_ASSERT     ( !::wxDirExists(path) );
-			FILE_ASSERT     ( !filename.FileExists() );
-			FILE_ASSERT     ( !::wxFileName::FileExists(path) );
-			FILE_ASSERT     ( !::wxFileExists(path) );
+			wxASSERT( !filename.IsDir() );
+			wxASSERT(  filename.DirExists() );
+			wxASSERT( !wxFileName::DirExists(path) );
+			wxASSERT( !::wxDirExists(path) );
+			wxASSERT( !filename.FileExists() );
+			wxASSERT( !::wxFileName::FileExists(path) );
+			wxASSERT( !::wxFileExists(path) );
 		}
 		{
 			wxString path = wxT("/unexistant/dir/");                                        // unexistant dir
 			wxFileName filename(path);
-			FILE_ASSERT     (  filename.IsDir() );
-			FILE_ASSERT     ( !filename.DirExists() );
-			FILE_ASSERT     ( !wxFileName::DirExists(path) );
-			FILE_ASSERT     ( !::wxDirExists(path) );
-			FILE_ASSERT     ( !filename.FileExists() );
-			FILE_ASSERT     ( !::wxFileName::FileExists(path) );
-			FILE_ASSERT     ( !::wxFileExists(path) );
+			wxASSERT(  filename.IsDir() );
+			wxASSERT( !filename.DirExists() );
+			wxASSERT( !wxFileName::DirExists(path) );
+			wxASSERT( !::wxDirExists(path) );
+			wxASSERT( !filename.FileExists() );
+			wxASSERT( !::wxFileName::FileExists(path) );
+			wxASSERT( !::wxFileExists(path) );
 		}
 		{
 			wxString path = wxT("/unexistant/unexistant.file");                             // unexistant file in unexistant dir
 			wxFileName filename(path);
-			FILE_ASSERT( !filename.IsDir() );
-			FILE_ASSERT( !filename.DirExists() );
-			FILE_ASSERT( !wxFileName::DirExists(path) );
-			FILE_ASSERT( !::wxDirExists(path) );
-			FILE_ASSERT( !filename.FileExists() );
-			FILE_ASSERT( !::wxFileName::FileExists(path) );
-			FILE_ASSERT( !::wxFileExists(path) );
+			wxASSERT( !filename.IsDir() );
+			wxASSERT( !filename.DirExists() );
+			wxASSERT( !wxFileName::DirExists(path) );
+			wxASSERT( !::wxDirExists(path) );
+			wxASSERT( !filename.FileExists() );
+			wxASSERT( !::wxFileName::FileExists(path) );
+			wxASSERT( !::wxFileExists(path) );
+			wxASSERT( !::wxFileExists("") ); // we rely on this when eg. wxFileSystem::URLToFileName(..).GetFullPath(); fails and returns the empty string
 		}
-		#undef FILE_ASSERT
 	}
 
 
@@ -390,8 +465,9 @@ void SjTestdrive1()
 				// see http://www.silverjuke.net/forum/topic-1196.html
 				sql.Query(wxT("INSERT INTO test (col1) VALUES ('Die ") +wxString(wxChar(0xc4))+ wxT("rzte');"));
 				sql.Query(wxT("SELECT * FROM test WHERE col1 LIKE 'die ") +wxString(wxChar(0xe4))+  wxT("%'"));
-				if( !sql.Next() )
-					wxLogWarning(wxT("Testdrive: sqlite3 LIKE-operator is not case insenssitive for german umlauts!"));
+				if( !sql.Next() ) {
+					wxLogInfo(wxT("Testdrive: sqlite3 LIKE-operator is not case insenssitive for german umlauts!"));
+				}
 
 				sql.Query(wxT("INSERT INTO test (col1) VALUES ('ABC');"));
 				sql.Query(wxT("SELECT * FROM test WHERE col1 LIKE 'abc'"));
@@ -431,6 +507,7 @@ void SjTestdrive1()
 
 	/* Scripting tests */
 	#if SJ_USE_SCRIPTS
+	if( g_debug&0x04 )
 	{
 		SjSee see;
 		see.SetExecutionScope(wxT("Testdrive"));
@@ -438,7 +515,7 @@ void SjTestdrive1()
 		see.Execute(wxT("2+2"));
 
 		if( see.GetResultString()!=wxT("4")
-		  || see.GetResultLong()!=4
+		 || see.GetResultLong()!=4
 		 || see.GetResultDouble()!=4.0 )
 		{
 			wxLogWarning(wxT("Testdrive: SjSee::Execute(\"2+2\") failed"));
@@ -454,9 +531,12 @@ void SjTestdrive1()
 			wxLogWarning(wxT("Testdrive: SjSee::Execute(\"function test ...\") failed"));
 		}
 
+		see.Execute("program.version");
+		wxASSERT( see.GetResultLong() == ((SJ_VERSION_MAJOR<<24)|(SJ_VERSION_MINOR<<16)|(SJ_VERSION_REVISION<<8)) );
+
 		wxString testStr;
-		testStr.Append(0xF6); // small german "o" with two points
-		testStr.Append(0x1F82); // greek extended alpha
+		testStr.Append((wxChar)0xF6); // small german "o" with two points
+		testStr.Append((wxChar)0x1F82); // greek extended alpha
 		see.Execute(wxT("test1='") + testStr + wxT("'; test2=test1; test2=encodeURI(test2); test2=decodeURI(test2); test1==test2;"));
 		if( !see.GetResultLong() )
 		{
@@ -475,9 +555,17 @@ void SjTestdrive1()
 		wxASSERT(!floatingpointstring.IsEmpty());
 	}
 
+	// other math tests
+	wxASSERT( SjTools::Rand(0) == 0 );
+	wxASSERT( SjTools::Rand(1) == 0 );
+
+	// check that our IDs do not overlap with the wxWidgets IDs
+	wxASSERT( wxID_LOWEST == IDO_wxID_LOWEST );
+	wxASSERT( wxID_HIGHEST == IDO_wxID_HIGHEST );
+	wxASSERT( wxID_LOWEST == 4999 );
+	wxASSERT( wxID_HIGHEST == 5999 );
+
 	/* Done */
 	wxLogInfo(wxT("Testdrive: Done."));
-
-	#endif // of (***)
 }
 
