@@ -404,6 +404,7 @@ enum SjIcon
     // large icons
 	,SJ_ICON_MUSICLIB = 1
     ,SJ_ICON_PLAYBACK_SETTINGS = 2
+	,SJ_ICON_FX_SETTINGS = 3
     ,SJ_ICON_SKIN = 4
     ,SJ_ICON_KIOSK = 5
     ,SJ_ICON_ADVANCED = 6
@@ -413,6 +414,7 @@ enum SjIcon
     ,SJ_ICON_ANYFILE = 10
     ,SJ_ICON_MUSIC_FILE = 11
     ,SJ_ICON_SKIN_FILE = 12
+    ,SJ_ICON_UPNP_SERVER = 16
     ,SJ_ICON_SWITCH = 17
     ,SJ_ICON_INTERNET_SERVER = 18
     ,SJ_ICON_MODULE = 19
@@ -621,7 +623,7 @@ public:
 	static bool     ParseNumber         (const wxString& str, long* retNumber=NULL);
 
 	static wxString FormatStdFloat      (float f); // returns an non-localized string, ready to save to INI etc.
-	static float    ParseFloat          (const wxString& str);
+	static float    ParseFloat          (const wxString& str, float defValue=1.0F); // the default value is 1.0; do not change this, users may rely on this!
 
 	static wxString FormatRect          (const wxRect&);
 	static wxRect   ParseRect           (const wxString&);
